#ifndef NT2_INCLUDE_FUNCTIONS_DOT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DOT_HPP_INCLUDED

#include <nt2/reduction/include/functions/dot.hpp>

#endif
